package com.akamai.media.demo4;

import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;

import android.app.Service;
import android.content.Intent;
import android.content.SharedPreferences;
import android.media.AudioManager;
import android.os.Bundle;
import android.os.IBinder;
import android.preference.PreferenceManager;
import android.util.Log;
import android.view.View;
import android.view.Window;
import android.widget.ImageView;
import android.widget.ProgressBar;
import android.widget.TextView;
import android.widget.Toast;

public class PlayerService extends Service implements IPlayerEventsListener
{
	private static String TAG = "PlayerService";
	
	private VideoPlayerView mVideoView;
    private VideoPlayerContainer mVideoContainer;
    
    public static boolean IsRunning = false;
	
	@Override
    public IBinder onBind(Intent arg0) 
	{
        return null;
    }
 
    @Override
    public void onCreate() 
    {
        Log.d(TAG, "onCreate");
    }
 
    @Override
    public void onStart(Intent intent, int startId) 
    {
    	Toast.makeText(getApplicationContext(), "START PLAYBACK", Toast.LENGTH_SHORT).show();
    	
    	try
    	{
	    	String sUrl = intent.getStringExtra("sUrl");
	        Log.d(TAG, "onStart: " + sUrl);
	        
	        SharedPreferences settings = PreferenceManager.getDefaultSharedPreferences(this);
			String sPlayerMode = settings.getString(PlayerConfiguration.PREFS_PLAYER_WORKING_MODE, "10");
	        Integer iPlayerMode = Integer.valueOf(sPlayerMode);
	        
	        String sMaxBitrateValue = settings.getString(PlayerConfiguration.PREFS_MAX_BITRATE, PlayerConfiguration.PREFS_MAX_BITRATE_DEFAULT_VALUE);
	        Integer iMaxBitrateValue = Integer.valueOf(sMaxBitrateValue);
	        
	        String sStartingBitrate = settings.getString(PlayerConfiguration.PREFS_HLS_START_ALGORITHM, PlayerConfiguration.PREFS_HLS_START_ALGORITHM_DEFAULT_VALUE);
	        Integer iStartingBitrate = Integer.valueOf(sStartingBitrate);
	        
	        String sNetsessionMode = settings.getString(PlayerConfiguration.PREFS_NETSESSION_MODE, PlayerConfiguration.PREFS_NETSESSION_MODE_DEFAULT_VALUE);
	        Integer iNetsessionMode = Integer.valueOf(sNetsessionMode);
	        
	        String sBufferSize = settings.getString(PlayerConfiguration.PREFS_BUFFER_SIZE, PlayerConfiguration.PREFS_BUFFER_SIZE_DEFAULT_VALUE);
	        Integer iBufferSize = Integer.valueOf(sBufferSize);
	        
	        boolean automaticBitrate = settings.getBoolean(PlayerConfiguration.PREFS_AUTO_SWITCHING, true);
	        boolean autoBufferMode = settings.getBoolean(PlayerConfiguration.PREFS_AUTO_BUFFER_MODE, true);
	        boolean useStartBuffer = settings.getBoolean(PlayerConfiguration.PREFS_USE_START_BUFFER, false);
	        boolean useMultithread = settings.getBoolean(PlayerConfiguration.PREFS_USE_MULTITHREAD, false);
	        
	        mVideoContainer = new VideoPlayerContainer(this);
	        
	        // Set the player mode
	        mVideoContainer.setMode(iPlayerMode);
	        mVideoView = mVideoContainer.getAudioPlayer();        
	        mVideoView.setEventsListener(this);
	        
	        mVideoView.setLicense("HHMALdN_yu_KrtsBWI7qH3Nn0N_KidMA6MtJzll5xlCyWcv37gy_UEOLv4mPxN1vXUIPWjxiRX1ZVUauvrg-5Q==");
	        Log.d("PlayerView", "License package: " + mVideoView.getLicensePackageName());
	        Log.d("PlayerView", "License expiration date: " + mVideoView.getLicenseExpirationDate());
	        
	        mVideoView.setUseMultiThread(useMultithread);
	        mVideoView.setDebugingActive(false);
	        mVideoView.setLogEnabled(true);
	        mVideoView.setHLSStartingAlgorithm(iStartingBitrate);
	        mVideoView.setNetSessionMode(iNetsessionMode);
	        mVideoView.setManualSwitching(!automaticBitrate);	        
	        mVideoView.setMaxBitrate(iMaxBitrateValue);
	        
	        if(autoBufferMode)
	        	mVideoView.setRebufferingMode(VideoPlayerView.MEDIA_REBUFFERING_MODE_AUTOMATIC);
	        else
	        {
	        	mVideoView.setRebufferingMode(VideoPlayerView.MEDIA_REBUFFERING_MODE_MANUAL);
	        	mVideoView.setRebufferingSize(iBufferSize*1024);
	        }
	        
	        mVideoView.setUseBufferingWhenStarting(!useStartBuffer);
	        
	        // Play the stream
	        mVideoView.playAudioUrl(sUrl);
	        
	        IsRunning = true;
    	}
    	catch(Exception ex)
    	{
    		Log.e(TAG, ex.toString());
    	}
    }
 
    @Override
    public void onDestroy() 
    {
        Log.d(TAG, "onDestroy");
        
        Toast.makeText(getApplicationContext(), "STOP PLAYBACK", Toast.LENGTH_SHORT).show();
        mVideoView.clearRenderBuffer();
        mVideoView.stop();
        
        IsRunning = false;
    }

	@Override
	public boolean onPlayerEvent(int iInEventType) {
		Log.d(TAG, "onPlayerEvent: " + iInEventType);
		// TODO Auto-generated method stub
		
		return true;
		
	}

	@Override
	public boolean onPlayerExtendedEvent(int iInEventType, int arg1, int arg2) {
		Log.d(TAG, "onPlayerExtendedEvent: " + iInEventType);
		// TODO Auto-generated method stub
		
		return true;
		
	}
}
