package com.akamai.media.demo4;


import android.content.Context;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.widget.FrameLayout;
import android.widget.SeekBar;
import android.widget.TextView;

public class PlayerSeekbarControls extends FrameLayout implements SeekBar.OnSeekBarChangeListener
{
	private PlayerVideoActivity mParent;
	private SeekBar mSeekbar;
	private TextView mSeekbarText;
	private TextView mSeekbarPosText;
	private long mLastChangePosRequest = 0;
	private final int TIME_TO_CHANGE = 2000;
	private Boolean mLive = false; 
	 
	public PlayerSeekbarControls(Context context, AttributeSet attrs)
	{
		super(context, attrs);
   
		mParent = (PlayerVideoActivity) context;
		
		setBackgroundColor(android.graphics.Color.argb(80, 190, 190, 190));
 
		// Here we build the child views in code
        LayoutInflater.from(context).inflate(R.layout.playerseekbar, this, true);
        mSeekbar = (SeekBar)findViewById(R.id.seekBarCtrl);
        mSeekbarText = (TextView)findViewById(R.id.seekBarTextCtrl);
        mSeekbarPosText = (TextView)findViewById(R.id.seekBarPositionCtrl);
        mSeekbar.setEnabled(true);   

        mSeekbar.setOnSeekBarChangeListener(this);
    }
	
	public Boolean isTouching()
	{
		return mSeekbar.isPressed();
	}
	
	public void DisableSeekBar()
	{
		mSeekbar.setEnabled(false);
		
	}
	
	public void setMax(int max)
	{
		if(max == 0)
		{
			mLive = true;
			mSeekbar.setMax(100);
			mSeekbar.setProgress(100);
			//mSeekbar.setEnabled(false);
			mSeekbarText.setText("Live   ");
			mSeekbarPosText.setVisibility(INVISIBLE);
		}
		else
		{
			mLive = false;
			mSeekbar.setMax(max);
			mSeekbar.setProgress(0);
			mSeekbar.setEnabled(true);
			
			mSeekbarText.setText(getStringFromSeconds(max));
		}
	}
	
	private String getStringFromSeconds(int sg)
	{
		String sRes = "00:00";
		
		int minutes = sg/60;
		if(minutes > 59)
		{
			int hours = sg/3600;
			minutes = (sg%3600)/60;
			sRes = String.format("%02d:%02d", hours, minutes);
		}
		else
		{
			int seconds = sg%60;
			sRes = String.format("%02d:%02d", minutes, seconds);
		}
		
		return sRes;
	}
	
	public void setProgress(int progress)
	{
		if(mLive)
			return;
		
		if(!isTouching() && (System.currentTimeMillis() - mLastChangePosRequest) > TIME_TO_CHANGE)
		{
			if(progress <= mSeekbar.getMax())
			{
				mSeekbar.setProgress(progress);
				mSeekbarPosText.setText(getStringFromSeconds(progress));
			}
		}
	}
	
	public void setFPS(long fps)
	{
		mSeekbarText.setText(fps + "   ");
	}

	@Override
	public void onProgressChanged(SeekBar seekBar, int progress,
			boolean fromUser) {
		if(fromUser)
		{
			
		}
	}

	@Override
	public void onStartTrackingTouch(SeekBar seekBar) {
		// TODO Auto-generated method stub
		
	}

	@Override
	public void onStopTrackingTouch(SeekBar seekBar) 
	{
		mLastChangePosRequest = System.currentTimeMillis();
		int position = seekBar.getProgress();
		mParent.seek(position);
		
		mSeekbarPosText.setText(getStringFromSeconds(position));
	}
}
